@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2022, Intel Corporation
+* Copyright (c) 2017-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -37,6 +37,7 @@
 
 #define CODEC_AVC_MAX_QP 51
 #define CODEC_AVC_MIN_QP_LP 10
+#define CODEC_AVC_MIN_QP1 1
 
 #define CODEC_AVC_NUM_WP_FRAME              8
 #define CODEC_AVC_MAX_FORWARD_WP_FRAME      6
@@ -726,6 +727,16 @@ typedef struct _CODEC_AVC_ENCODE_PIC_PARAMS
     *   RefFrameList[] should include all the reference pictures in DPB, which means either the picture is referred by current picture or future pictures, it should have a valid entry in it.
     */
     CODEC_PICTURE   RefFrameList[CODEC_AVC_MAX_NUM_REF_FRAME];
+
+
+    /*! \brief Each entry of the list specifies the frame resource of the reference pictures.
+    *
+    *   The value of FrameIdx is the same as the reference frame index saved in RefList. And valid value range is [0..14, 0x7F]. 
+    *   RefFrameList[] should include all the reference pictures in DPB, which means either the picture is referred by current picture or future pictures, it should have a valid entry in it.
+    *   currently only for Vulkan encode
+    */
+    MOS_SURFACE     RefFrameListSurface[CODEC_AVC_MAX_NUM_REF_FRAME]; 
+
     /*! \brief Denotes "used for reference" frames as defined in the AVC specification.
     *
     *   The flag is accessed by:
@@ -1050,6 +1061,8 @@ typedef struct _CODEC_AVC_ENCODE_PIC_PARAMS
     */
     uint8_t         QpModulationStrength;
 
+    uint8_t         AdaptiveTUEnabled;
+
     /*! \brief StatusReportEnable
     *
     *  Request features to be enabled at status report.
@@ -1067,6 +1080,17 @@ typedef struct _CODEC_AVC_ENCODE_PIC_PARAMS
         uint16_t value;
     } StatusReportEnable;
 
+    /*! \brief quality information report enable flags.
+    */
+    union
+    {
+        struct
+        {
+            uint8_t enable_frame : 1;
+            uint8_t reserved : 7;
+        } fields;
+        uint8_t value;
+    } QualityInfoSupportFlags;
 } CODEC_AVC_ENCODE_PIC_PARAMS, *PCODEC_AVC_ENCODE_PIC_PARAMS;
 
 /*! \brief Slice-level parameters of a compressed picture for AVC encoding.
