@@ -469,7 +469,15 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_LOCKABLE_RESOURCE_ID,
     __MEDIA_USER_FEATURE_VALUE_MMC_ENC_POST_CDEF_RECON_COMPRESSIBLE_ID,
     __MEDIA_USER_FEATURE_VALUE_MMC_ENC_POST_CDEF_RECON_COMPRESSMODE_ID,
-
+#if (_DEBUG || _RELEASE_INTERNAL)
+    __MEDIA_USER_FEATURE_VALUE_FINE_GRANULAR_CRC_POISON_ID,
+    __MEDIA_USER_FEATURE_VALUE_POSION_NTH_FINE_GRANULAR_CRC_ID,
+    __MEDIA_USER_FEATURE_VALUE_FINE_GRANULAR_CRC_STREAMOUT_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_FINE_GRANULAR_CRC_STREAMIN_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_FINE_GRANULAR_CRC_OUTPUT_RATE_ID,
+    __MEDIA_USER_FEATURE_VALUE_DECODE_AVC_HW_STARTCODE_SUPPORT_DISABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_VDBOX_CRC_OUTPUT_ENABLE_ID,
+#endif
     __MOS_USER_FEATURE_KEY_MAX_ID,
 } MOS_USER_FEATURE_VALUE_ID;
 
