@@ -33,6 +33,7 @@
 #endif
 #include "vphal_render_vebox_xe_hpm.h"
 #include "vphal_render_composite_xe_xpm.h"
+#include "vp_debug.h"
 
 extern const Kdll_RuleEntry         g_KdllRuleTable_Xe_Hpm[];
 
@@ -585,7 +586,7 @@ MOS_STATUS VphalRendererXe_Hpm::RenderScaling(
         dwAllocatedWidth                = pTarget->dwWidth;
         dwAllocatedHeight               = pTarget->dwHeight;
         VPHAL_RENDER_CHK_STATUS(AllocateSurface(pRenderParams, pSource, m_pDSSurface[1], dwAllocatedWidth, dwAllocatedHeight, pSource->Format));
-        rectScalingRegion               = pTarget->rcDst;
+        rectScalingRegion               = pSource->rcDst;
         m_pDSSurface[0]->rcDst          = rectScalingRegion;
         m_pDSSurface[1]->rcDst          = rectScalingRegion;
 
@@ -596,7 +597,7 @@ MOS_STATUS VphalRendererXe_Hpm::RenderScaling(
         VPHAL_RENDER_CHK_STATUS(RenderPass(&renderParams));
         m_pDSSurface[1]->rcSrc           = m_pDSSurface[1]->rcDst;
         m_pDSSurface[1]->rcMaxSrc        = m_pDSSurface[1]->rcDst;
-        m_pDSSurface[1]->rcDst           = pTarget->rcDst;
+        m_pDSSurface[1]->rcDst           = pSource->rcDst;
         pDSSurface                       = m_pDSSurface[1];
     }
 
