@@ -130,8 +130,12 @@ bool CmEventExBase::LogTimestamps(const char *callerFunctionName, int callerLine
     {
         return false;
     }
-    CmLogger::GetInstance(m_cmhal).Print(CM_LOG_LEVEL_DEBUG, __FILE__,
+    CmLogger* logTmp = CmLogger::GetInstance(m_cmhal);
+    if(logTmp != nullptr)
+    {
+        logTmp->Print(CM_LOG_LEVEL_DEBUG, __FILE__,
                                          callerLineNumber, log_stream.str());
+    }
 #endif  // #if CM_LOG_ON
     return true;
 }
