@@ -29,6 +29,7 @@
 #include "cm_kernel_ex.h"
 #include "cm_scratch_space.h"
 #include "mos_solo_generic.h"
+#include "mos_os_cp_interface_specific.h"
 
 #include <string>
 #include <iostream>
@@ -51,8 +52,7 @@ CmSSH::CmSSH(CM_HAL_STATE *cmhal, PMOS_COMMAND_BUFFER cmdBuf):
     m_curSsIndex(0),
     m_cmhal(cmhal),
     m_renderhal(nullptr),
-    m_resCount(0),
-    m_occupiedBteIndexes(nullptr)
+    m_resCount(0)
 {
 }
 
@@ -546,7 +546,8 @@ void CmSSH::DumpSSH()
         static int fileCount = 0;
         stringstream filename;
         filename << "HALCM_Surface_State_Dumps" << PLATFORM_DIR_SEPERATOR << "ssh_" << fileCount++ << ".fast.log";
-        GetLogFileLocation(filename.str().c_str(), fileNamePrefix);
+        GetLogFileLocation(filename.str().c_str(), fileNamePrefix,
+                           m_cmhal->osInterface->pOsContext);
 
         fstream sshFile;
         sshFile.open(fileNamePrefix, ios_base::out);
