@@ -37,7 +37,11 @@ CodechalDecodeHistogramVebox::CodechalDecodeHistogramVebox(
     MOS_ZeroMemory(&m_resStatisticsOutput, sizeof(m_resStatisticsOutput));
     MOS_ZeroMemory(&m_outputSurface, sizeof(m_outputSurface));
     // allocate heap
-    m_veboxInterface->CreateHeap();
+    MOS_STATUS status = m_veboxInterface->CreateHeap();
+    if (status != MOS_STATUS_SUCCESS)
+    {
+        CODECHAL_DECODE_ASSERTMESSAGE("Failed to CreateHeap.");
+    }
 
     // create Vebox context
     MOS_GPUCTX_CREATOPTIONS  createOpts;
@@ -461,7 +465,7 @@ MOS_STATUS CodechalDecodeHistogramVebox::RenderHistogram(
     MOS_ZeroMemory(&userFeatureWriteData, sizeof(userFeatureWriteData));
     userFeatureWriteData.Value.i32Data = 1;
     userFeatureWriteData.ValueID       = __MEDIA_USER_FEATURE_VALUE_DECODE_HISTOGRAM_FROM_VEBOX_ID;
-    MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
+    MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1, m_osInterface->pOsContext);
 
     return eStatus;
 }
