@@ -30,6 +30,7 @@
 
 #include "mhw_mi.h"
 #include "mhw_cp_interface.h"
+#include "mos_os_cp_interface_specific.h"
 
 template <class TMiCmds>
 class MhwMiInterfaceGeneric : public MhwMiInterface
@@ -123,19 +124,20 @@ private:
         PMOS_COMMAND_BUFFER cmdBuffer,
         bool isRender)
     {
-        MOS_STATUS    eStatus    = MOS_STATUS_SUCCESS;
-        PMOS_RESOURCE pResMarker = NULL;
+        MOS_STATUS      eStatus     = MOS_STATUS_SUCCESS;
+        PMOS_RESOURCE   resMarker   = nullptr;
 
         MHW_FUNCTION_ENTER;
 
-        pResMarker = m_osInterface->pfnGetMarkerResource(m_osInterface);
+        resMarker = m_osInterface->pfnGetMarkerResource(m_osInterface);
+        MHW_CHK_NULL_RETURN(resMarker);
 
         if (isRender)
         {
             // Send pipe_control to get the timestamp
             MHW_PIPE_CONTROL_PARAMS             pipeControlParams;
             MOS_ZeroMemory(&pipeControlParams, sizeof(pipeControlParams));
-            pipeControlParams.presDest          = pResMarker;
+            pipeControlParams.presDest          = resMarker;
             pipeControlParams.dwResourceOffset  = sizeof(uint64_t);
             pipeControlParams.dwPostSyncOp      = MHW_FLUSH_WRITE_TIMESTAMP_REG;
             pipeControlParams.dwFlushMode       = MHW_FLUSH_WRITE_CACHE;
@@ -147,15 +149,17 @@ private:
             // Send flush_dw to get the timestamp
             MHW_MI_FLUSH_DW_PARAMS  flushDwParams;
             MOS_ZeroMemory(&flushDwParams, sizeof(flushDwParams));
-            flushDwParams.pOsResource           = pResMarker;
+            flushDwParams.pOsResource           = resMarker;
             flushDwParams.dwResourceOffset      = sizeof(uint64_t);
             flushDwParams.postSyncOperation     = MHW_FLUSH_WRITE_TIMESTAMP_REG;
             flushDwParams.bQWordEnable          = 1;
 
             MHW_MI_CHK_STATUS(AddMiFlushDwCmd(cmdBuffer, &flushDwParams));
         }
-
-        MOS_SafeFreeMemory(pResMarker);
+        if (!m_osInterface->apoMosEnabled)
+        {
+            MOS_SafeFreeMemory(resMarker);
+        }
         return eStatus;
     }
 
@@ -181,6 +185,7 @@ public:
 
         typename TMiCmds::MI_NOOP_CMD cmd;
         MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(
+            m_osInterface,
             cmdBuffer,
             batchBuffer,
             &cmd,
@@ -220,13 +225,14 @@ public:
         // However, since the 2nd level BB always returens to the 1st level BB and
         // no chained BB scenario in Media, Epilog is only needed in the 1st level BB.
         // Therefre, here only the 1st level BB case needs an Epilog inserted.
-        if (cmdBuffer)
+        if (cmdBuffer && cmdBuffer->is1stLvlBB)
         {
             MHW_MI_CHK_STATUS(m_cpInterface->AddEpilog(m_osInterface, cmdBuffer));
         }
 
         typename TMiCmds::MI_BATCH_BUFFER_END_CMD cmd;
         MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(
+            m_osInterface,
             cmdBuffer,
             batchBuffer,
             &cmd,
@@ -240,12 +246,14 @@ public:
         }
 
         // Send End Marker command
-        if (m_osInterface->pfnIsSetMarkerEnabled(m_osInterface))
+        if (m_osInterface->pfnIsSetMarkerEnabled(m_osInterface) && cmdBuffer && cmdBuffer->is1stLvlBB)
         {
             MHW_MI_CHK_STATUS(SendMarkerCommand(
                 cmdBuffer, MOS_RCS_ENGINE_USED(m_osInterface->pfnGetGpuContext(m_osInterface))));
         }
 
+        MHW_MI_CHK_STATUS(m_osInterface->osCpInterface->PermeateBBPatchForHM());
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -266,13 +274,14 @@ public:
         // However, since the 2nd level BB always returens to the 1st level BB and
         // no chained BB scenario in Media, Epilog is only needed in the 1st level BB.
         // Therefre, here only the 1st level BB case needs an Epilog inserted.
-        if (cmdBuffer)
+        if (cmdBuffer && cmdBuffer->is1stLvlBB)
         {
             MHW_MI_CHK_STATUS(m_cpInterface->AddEpilog(m_osInterface, cmdBuffer));
         }
 
         typename TMiCmds::MI_BATCH_BUFFER_END_CMD cmd;
         MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(
+            m_osInterface,
             cmdBuffer,
             batchBuffer,
             &cmd,
@@ -286,7 +295,7 @@ public:
         }
 
         // Send End Marker command
-        if (m_osInterface->pfnIsSetMarkerEnabled(m_osInterface))
+        if (m_osInterface->pfnIsSetMarkerEnabled(m_osInterface) && cmdBuffer && cmdBuffer->is1stLvlBB)
         {
             MHW_MI_CHK_STATUS(SendMarkerCommand(
                 cmdBuffer, MOS_RCS_ENGINE_USED(m_osInterface->pfnGetGpuContext(m_osInterface))));
@@ -301,6 +310,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->pOsResource);
@@ -328,7 +338,7 @@ public:
 
         cmd.DW3.DataDword0 = params->dwValue;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -342,52 +352,6 @@ public:
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
-        typename TMiCmds::MI_FLUSH_DW_CMD cmd;
-
-        // set the protection bit based on CP status
-        MHW_MI_CHK_STATUS(m_cpInterface->SetProtectionSettingsForMiFlushDw(m_osInterface, &cmd));
-
-        cmd.DW0.VideoPipelineCacheInvalidate    = params->bVideoPipelineCacheInvalidate;
-        cmd.DW0.PostSyncOperation               = cmd.POST_SYNC_OPERATION_NOWRITE;
-        cmd.DW3_4.Value[0]                      = params->dwDataDW1;
-
-        if (params->pOsResource)
-        {
-            cmd.DW0.PostSyncOperation           = cmd.POST_SYNC_OPERATION_WRITEIMMEDIATEDATA;
-            cmd.DW1_2.DestinationAddressType    = UseGlobalGtt.m_vcs;
-
-            MHW_RESOURCE_PARAMS resourceParams;
-            MOS_ZeroMemory(&resourceParams, sizeof(resourceParams));
-            resourceParams.presResource     = params->pOsResource;
-            resourceParams.dwOffset         = params->dwResourceOffset;
-            resourceParams.pdwCmd           = cmd.DW1_2.Value;
-            resourceParams.dwLocationInCmd  = 1;
-            resourceParams.dwLsbNum         = MHW_COMMON_MI_FLUSH_DW_SHIFT;
-            resourceParams.HwCommandType    = MOS_MI_FLUSH_DW;
-            resourceParams.bIsWritable      = true;
-
-            MHW_MI_CHK_STATUS(AddResourceToCmd(
-                m_osInterface,
-                cmdBuffer,
-                &resourceParams));
-        }
-
-        if (params->postSyncOperation)
-        {
-            cmd.DW0.PostSyncOperation = params->postSyncOperation;
-        }
-
-        if (params->dwDataDW2 || params->bQWordEnable)
-        {
-            cmd.DW3_4.Value[1] = params->dwDataDW2;
-        }
-        else
-        {
-            cmd.DW0.DwordLength--;
-        }
-
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
-
         return MOS_STATUS_SUCCESS;
     }
 
@@ -397,6 +361,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->presSrc);
@@ -435,7 +400,7 @@ public:
             cmdBuffer,
             &resourceParams));
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -446,6 +411,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->presStoreBuffer);
@@ -469,7 +435,7 @@ public:
         cmd.DW0.UseGlobalGtt = IsGlobalGttInUse();
         cmd.DW1.RegisterAddress = params->dwRegister >> 2;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -480,6 +446,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->presStoreBuffer);
@@ -503,7 +470,7 @@ public:
         cmd.DW0.UseGlobalGtt    = IsGlobalGttInUse();
         cmd.DW1.RegisterAddress = params->dwRegister >> 2;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -514,6 +481,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -521,7 +489,7 @@ public:
         cmd.DW1.RegisterOffset = params->dwRegister >> 2;
         cmd.DW2.DataDword = params->dwData;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -532,6 +500,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -539,7 +508,7 @@ public:
         cmd.DW1.SourceRegisterAddress = params->dwSrcRegister >> 2;
         cmd.DW2.DestinationRegisterAddress = params->dwDstRegister >> 2;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -550,6 +519,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -562,9 +532,9 @@ public:
         typename TMiCmds::MI_MATH_CMD cmd;
         cmd.DW0.DwordLength = params->dwNumAluParams - 1;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(
             cmdBuffer,
             &params->pAluPayload[0],
             sizeof(MHW_MI_ALU_PARAMS)* params->dwNumAluParams));
@@ -578,11 +548,12 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
 
         typename TMiCmds::MI_SET_PREDICATE_CMD cmd;
         cmd.DW0.PredicateEnable = enableFlag;
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -593,6 +564,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->pOsResource);
@@ -671,7 +643,7 @@ public:
             cmd.DW10.Operand2DataDword3 = params->dwOperand2Data[3];
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -682,6 +654,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->presSemaphoreMem);
@@ -707,7 +680,7 @@ public:
         cmd.DW0.CompareOperation    = params->CompareOperation;
         cmd.DW1.SemaphoreDataDword  = params->dwSemaphoreData;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -717,10 +690,11 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
 
         typename TMiCmds::MI_ARB_CHECK_CMD cmd;
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -832,7 +806,7 @@ public:
             cmd.DW1.IndirectStatePointersDisable = true;
         }
 
-        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -856,7 +830,7 @@ public:
         // set the protection bit based on CP status
         MHW_MI_CHK_STATUS(m_cpInterface->SetProtectionSettingsForMfxWait(m_osInterface, &cmd));
 
-        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -868,29 +842,12 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
-        if (cmdBuffer == nullptr && batchBuffer == nullptr)
+       if (cmdBuffer == nullptr && batchBuffer == nullptr)
         {
             MHW_ASSERTMESSAGE("There was no valid buffer to add the HW command to.");
             return MOS_STATUS_NULL_POINTER;
         }
 
-        typename TMiCmds::MEDIA_STATE_FLUSH_CMD cmd;
-
-        if (params != nullptr)
-        {
-            cmd.DW1.FlushToGo = params->bFlushToGo;
-            cmd.DW1.InterfaceDescriptorOffset = params->ui8InterfaceDescriptorOffset;
-        }
-
-        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
-
-#if (_DEBUG || _RELEASE_INTERNAL)
-        if (batchBuffer)
-        {
-            batchBuffer->iLastCurrent = batchBuffer->iCurrent;
-        }
-#endif
-
         return MOS_STATUS_SUCCESS;
     }
 
@@ -901,29 +858,6 @@ public:
 
         MHW_MI_CHK_NULL(batchBuffer);
 
-        auto waTable = m_osInterface->pfnGetWaTable(m_osInterface);
-        MHW_MI_CHK_NULL(waTable);
-
-        // This WA does not apply for video or other engines, render requirement only
-        bool isRender =
-            MOS_RCS_ENGINE_USED(m_osInterface->pfnGetGpuContext(m_osInterface));
-
-        if (isRender && (MEDIA_IS_WA(waTable, WaMSFWithNoWatermarkTSGHang) ||
-            MEDIA_IS_WA(waTable, WaAddMediaStateFlushCmd)))
-        {
-            typename TMiCmds::MEDIA_STATE_FLUSH_CMD FlushCmd;
-            MHW_MI_CHK_STATUS(Mhw_AddCommandBB(
-                batchBuffer,
-                nullptr,
-                FlushCmd.byteSize));
-        }
-
-        typename TMiCmds::MI_BATCH_BUFFER_END_CMD cmd;
-        MHW_MI_CHK_STATUS(Mhw_AddCommandBB(
-            batchBuffer,
-            nullptr,
-            cmd.byteSize));
-
         return MOS_STATUS_SUCCESS;
     }
 
