@@ -29,6 +29,7 @@
 #define _MHW_VDBOX_HUC_GENERIC_H_
 
 #include "mhw_vdbox_huc_interface.h"
+#include "mhw_cp_interface.h"
 
 //!  MHW Vdbox Huc generic interface
 /*!
@@ -280,6 +281,7 @@ protected:
         MOS_COMMAND_BUFFER                  *cmdBuffer,
         MHW_VDBOX_PIPE_MODE_SELECT_PARAMS   *params)
     {
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -293,7 +295,7 @@ protected:
         cmd.DW1.IndirectStreamOutEnable = params->bStreamOutEnabled;
         cmd.DW2.MediaSoftResetCounterPer1000Clocks = params->dwMediaSoftResetCounterValue;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -302,6 +304,7 @@ protected:
         MOS_COMMAND_BUFFER                  *cmdBuffer,
         MHW_VDBOX_HUC_IMEM_STATE_PARAMS     *params)
     {
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -309,7 +312,7 @@ protected:
 
         cmd.DW4.HucFirmwareDescriptor = params->dwKernelDescriptor;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -318,7 +321,7 @@ protected:
         MOS_COMMAND_BUFFER                  *cmdBuffer,
         MHW_VDBOX_HUC_DMEM_STATE_PARAMS     *params)
     {
-
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -350,7 +353,7 @@ protected:
             cmd.DW5.HucDataLength = params->dwDataLength >> MHW_VDBOX_HUC_GENERAL_STATE_SHIFT;
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -359,6 +362,7 @@ protected:
         MOS_COMMAND_BUFFER                  *cmdBuffer,
         MHW_VDBOX_HUC_VIRTUAL_ADDR_PARAMS   *params)
     {
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -390,7 +394,7 @@ protected:
             }
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -399,6 +403,7 @@ protected:
         MOS_COMMAND_BUFFER                  *cmdBuffer,
         MHW_VDBOX_IND_OBJ_BASE_ADDR_PARAMS  *params)
     {
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -445,7 +450,7 @@ protected:
                 &resourceParams));
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -454,6 +459,7 @@ protected:
         MOS_COMMAND_BUFFER                  *cmdBuffer,
         MHW_VDBOX_HUC_STREAM_OBJ_PARAMS     *params)
     {
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -472,7 +478,7 @@ protected:
         cmd.DW4.StartCodeByte1 = params->ucStartCodeByte1;
         cmd.DW4.StartCodeByte0 = params->ucStartCodeByte0;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -481,6 +487,7 @@ protected:
         MOS_COMMAND_BUFFER             *cmdBuffer,
         bool                            lastStreamObject)
     {
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
 
         typename THucCmds::HUC_START_CMD cmd;
@@ -488,7 +495,7 @@ protected:
         // set last stream object or not
         cmd.DW1.Laststreamobject = (lastStreamObject != 0);
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return MOS_STATUS_SUCCESS;
     }
