@@ -27,7 +27,7 @@
 #ifndef __VPHAL_RENDER_VEBOX_DENOISE_H__
 #define __VPHAL_RENDER_VEBOX_DENOISE_H__
 
-#include "renderhal.h"
+#include "renderhal_legacy.h"
 
 #if !EMUL
 #include "vphal_mdf_wrapper.h"
@@ -77,7 +77,7 @@ public:
     }
 
 private:
-    void AllocateResouces(const uint32_t width, const uint32_t height);
+    void AllocateResources(const uint32_t width, const uint32_t height);
     void FreeResources();
 
     EventManager*                m_eventManager            = nullptr;
