@@ -166,7 +166,7 @@ public:
 
 protected:
     // Renderer private data
-    PRENDERHAL_INTERFACE        m_pRenderHal;
+    PRENDERHAL_INTERFACE_LEGACY m_pRenderHal;
     PMOS_INTERFACE              m_pOsInterface;
     MediaUserSettingSharedPtr   m_userSettingPtr = nullptr;   //!< usersettingInstance
     // Auxiliary
