@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2018, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -73,12 +73,7 @@ MOS_STATUS CodechalDecodeJpegG11::SetGpuCtxCreatOption(
                 MOS_GPU_NODE_VIDEO,
                 m_gpuCtxCreatOpt));
 
-            MOS_GPUCTX_CREATOPTIONS createOption;
-            CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnCreateGpuContext(
-                m_osInterface,
-                MOS_GPU_CONTEXT_VIDEO,
-                MOS_GPU_NODE_VIDEO,
-                &createOption));
+            m_videoContext = MOS_GPU_CONTEXT_VIDEO;
         }
         else
         {
@@ -166,6 +161,21 @@ MOS_STATUS CodechalDecodeJpegG11::DecodeStateLevel()
         }
     }
 
+    if (m_decodeParams.m_destSurface->Format == Format_A8R8G8B8)
+    {
+        CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSetGpuContext(
+            m_osInterface,
+            MOS_GPU_CONTEXT_VIDEO4));
+        m_videoContext = MOS_GPU_CONTEXT_VIDEO4;
+    }
+    else
+    {
+        CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSetGpuContext(
+            m_osInterface,
+            MOS_GPU_CONTEXT_VIDEO));
+        m_videoContext = MOS_GPU_CONTEXT_VIDEO;
+    }
+
     MOS_COMMAND_BUFFER cmdBuffer;
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnGetCommandBuffer(
         m_osInterface,
@@ -209,9 +219,7 @@ MOS_STATUS CodechalDecodeJpegG11::DecodeStateLevel()
     pipeBufAddrParams.pDecodedReconParam = &surfaceParams;
     pipeBufAddrParams.psRawSurface = nullptr;
 
-#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetPipeBufAddr(&pipeBufAddrParams, &cmdBuffer));
-#endif
 
     pipeBufAddrParams.pDecodedReconParam = nullptr;
 
@@ -309,7 +317,7 @@ MOS_STATUS CodechalDecodeJpegG11::DecodePrimitiveLevel()
     MHW_VDBOX_QM_PARAMS qmParams;
     MOS_ZeroMemory(&qmParams, sizeof(qmParams));
     qmParams.Standard = CODECHAL_JPEG;
-    qmParams.pJpegQuantMatrix = (CodecJpegQuantMatrix *)m_jpegQMatrix;
+    qmParams.pJpegQuantMatrix = m_jpegQMatrix;
 
     // Swapping QM(x,y) to QM(y,x) for 90/270 degree rotation
     if ((m_jpegPicParams->m_rotation == jpegRotation90) ||
@@ -510,12 +518,7 @@ MOS_STATUS CodechalDecodeJpegG11::DecodePrimitiveLevel()
         CodecHalDecodeSinglePipeVE_PopulateHintParams(m_veState, &cmdBuffer, true);
     }
 
-    if (m_osInterface->osCpInterface->IsHMEnabled())
-    {
-        HalOcaInterface::DumpCpParam(cmdBuffer, *m_osInterface->pOsContext, m_osInterface->osCpInterface->GetOcaDumper());
-    }
-
-    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface);
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
         m_osInterface,
@@ -582,6 +585,6 @@ CodechalDecodeJpegG11::CodechalDecodeJpegG11(
 
     CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(m_osInterface);
 
-    Mos_CheckVirtualEngineSupported(m_osInterface, true, true);
+    m_osInterface->pfnVirtualEngineSupported(m_osInterface, true, true);
 }
 
