@@ -1,6 +1,6 @@
 /*===================== begin_copyright_notice ==================================
 
-Copyright (c) 2017-2019, Intel Corporation
+Copyright (c) 2017-2020, Intel Corporation
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -71,10 +71,6 @@ const uint32_t RowStoreCacheAddrVP9[13][4] =
 
 struct MHW_VDBOX_PIPE_MODE_SELECT_PARAMS_G12 : public MHW_VDBOX_PIPE_MODE_SELECT_PARAMS
 {
-    // GEN11+ specific
-    MHW_VDBOX_HCP_PIPE_WORK_MODE      PipeWorkMode = MHW_VDBOX_HCP_PIPE_WORK_MODE_LEGACY;
-    MHW_VDBOX_HCP_MULTI_ENGINE_MODE   MultiEngineMode = MHW_VDBOX_HCP_MULTI_ENGINE_MODE_FE_LEGACY;
-
     // GEN12 specific
     bool                        bTileBasedReplayMode = false;
     bool                        bWirelessEncodeEnabled = false;
@@ -86,6 +82,11 @@ struct MHW_VDBOX_PIPE_MODE_SELECT_PARAMS_G12 : public MHW_VDBOX_PIPE_MODE_SELECT
     bool                        bStreamingBufferEnabled = false;
     bool                        bIsRandomAccess = false;
     bool                        bLookaheadPass = false;
+    bool                        bAdaptiveRounding = false;
+    uint8_t                     tuMinus1 = 3;
+    uint8_t                     ucQuantizationPrecision = 0;
+    uint8_t                     tuSettingsRevision = 0;
+    bool                        frameReconDisable = false;
 };
 using PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS_G12 = MHW_VDBOX_PIPE_MODE_SELECT_PARAMS_G12 *;
 
@@ -93,6 +94,8 @@ struct MHW_VDBOX_AVC_IMG_PARAMS_G12 : public MHW_VDBOX_AVC_IMG_PARAMS
 {
     bool                        bVDEncUltraModeEnabled = false;
     bool                        oneOnOneMapping        = false;
+    bool                        bStreamInMbQpEnabled   = false;
+    uint8_t                     tuSettingsRevision     = 0;
 };
 using PMHW_VDBOX_AVC_IMG_PARAMS_G12 = MHW_VDBOX_AVC_IMG_PARAMS_G12 *;
 
