@@ -1477,7 +1477,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_G8_BASE::SetupSurfaceStatesForDenoise()
     MOS_ZeroMemory(&SurfaceParams, sizeof(SurfaceParams));
 
     SurfaceParams.Type              = pRenderHal->SurfaceTypeDefault;
-    SurfaceParams.bRenderTarget     = true;
+    SurfaceParams.isOutput     = true;
     SurfaceParams.bWidthInDword_Y   = true;
     SurfaceParams.bWidthInDword_UV  = true;
     SurfaceParams.Boundary          = RENDERHAL_SS_BOUNDARY_ORIGINAL;
@@ -1496,7 +1496,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_G8_BASE::SetupSurfaceStatesForDenoise()
     MOS_ZeroMemory(&SurfaceParams, sizeof(SurfaceParams));
 
     SurfaceParams.Type              = pRenderHal->SurfaceTypeDefault;
-    SurfaceParams.bRenderTarget     = true;
+    SurfaceParams.isOutput     = true;
     SurfaceParams.bWidthInDword_Y   = true;
     SurfaceParams.bWidthInDword_UV  = true;
     SurfaceParams.Boundary          = RENDERHAL_SS_BOUNDARY_ORIGINAL;
