@@ -50,8 +50,8 @@ CmDeviceRT::CmDeviceRT(uint32_t options) : CmDeviceRTBase(options)
 //*-----------------------------------------------------------------------------
 CmDeviceRT::~CmDeviceRT()
 {
-    m_mosContext->SkuTable.reset();
-    m_mosContext->WaTable.reset();
+    m_mosContext->m_skuTable.reset();
+    m_mosContext->m_waTable.reset();
 
     DestroyAuxDevice();
 };
@@ -166,7 +166,7 @@ int32_t CmDeviceRT::CreateAuxDevice(MOS_CONTEXT *mosContext)  //VADriverContextP
     CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(cmHalState->pfnCmAllocate(cmHalState));
 
     // allocate cmContext
-    cmContext = (PCM_CONTEXT)MOS_AllocAndZeroMemory(sizeof(CM_CONTEXT));
+    cmContext = (PCM_CONTEXT)MOS_New(CM_CONTEXT);
     CM_CHK_NULL_GOTOFINISH_CMERROR(cmContext);
     cmContext->mosCtx     = *mosContext; // mos context
     cmContext->cmHalState = cmHalState;
@@ -194,11 +194,11 @@ int32_t CmDeviceRT::DestroyAuxDevice()
     // Delete VPHAL State
     if (cmData && cmData->cmHalState)
     {
-        cmData->mosCtx.SkuTable.reset();
-        cmData->mosCtx.WaTable.reset();
+        cmData->mosCtx.m_skuTable.reset();
+        cmData->mosCtx.m_waTable.reset();
         HalCm_Destroy(cmData->cmHalState);
         // Delete CM Data itself
-        MOS_FreeMemory(cmData);
+        MOS_Delete(cmData);
 
     }
 
