@@ -280,6 +280,7 @@ static struct GfxDeviceInfo sklGt1Info = {
     .productFamily = IGFX_SKYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT1,
     .L3CacheSizeInKb = 384,
     .L3BankCount   = 2,
@@ -300,6 +301,7 @@ static struct GfxDeviceInfo sklGt1f5Info = {
     .productFamily = IGFX_SKYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT1_5,
     .L3CacheSizeInKb = 768,
     .L3BankCount   = 4,
@@ -320,6 +322,7 @@ static struct GfxDeviceInfo sklGt2Info = {
     .productFamily = IGFX_SKYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT2,
     .L3CacheSizeInKb = 768,
     .L3BankCount   = 4,
@@ -340,6 +343,7 @@ static struct GfxDeviceInfo sklGt3Info = {
     .productFamily = IGFX_SKYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT3,
     .L3CacheSizeInKb = 1536,
     .L3BankCount   = 8,
@@ -360,6 +364,7 @@ static struct GfxDeviceInfo sklGt3eInfo = {
     .productFamily = IGFX_SKYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT3,
     .L3CacheSizeInKb = 1536,
     .L3BankCount   = 8,
@@ -380,6 +385,7 @@ static struct GfxDeviceInfo sklGt4Info = {
     .productFamily = IGFX_SKYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT4,
     .L3CacheSizeInKb = 2304,
     .L3BankCount   = 12,
@@ -400,6 +406,7 @@ static struct GfxDeviceInfo sklGt4eInfo = {
     .productFamily = IGFX_SKYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT4,
     .L3CacheSizeInKb = 2304,
     .L3BankCount   = 12,
@@ -420,9 +427,31 @@ static struct GfxDeviceInfo bxtGt1Info = {
     .productFamily = IGFX_BROXTON,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT1,
     .L3CacheSizeInKb = 384,
     .L3BankCount   = 2,
+    .EUCount       = 12,
+    .SliceCount    = 1,
+    .SubSliceCount = 2,
+    .MaxEuPerSubSlice = 6,
+    .isLCIA        = 1,
+    .hasLLC        = 0,
+    .hasERAM       = 0,
+    .InitMediaSysInfo = InitLCIAMediaSysInfo,
+    .InitShadowSku    = InitLCIAShadowSku,
+    .InitShadowWa     = InitLCIAShadowWa,
+};
+
+static struct GfxDeviceInfo bxtGt1f5Info = {
+    .platformType  = PLATFORM_MOBILE,
+    .productFamily = IGFX_BROXTON,
+    .displayFamily = IGFX_GEN9_CORE,
+    .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
+    .eGTType       = GTTYPE_GT1_5,
+    .L3CacheSizeInKb = 384,
+    .L3BankCount   = 2,
     .EUCount       = 18,
     .SliceCount    = 1,
     .SubSliceCount = 3,
@@ -440,6 +469,28 @@ static struct GfxDeviceInfo glkGt1Info = {
     .productFamily = IGFX_GEMINILAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
+    .eGTType       = GTTYPE_GT1,
+    .L3CacheSizeInKb = 384,
+    .L3BankCount   = 2,
+    .EUCount       = 12,
+    .SliceCount    = 1,
+    .SubSliceCount = 2,
+    .MaxEuPerSubSlice = 6,
+    .isLCIA        = 1,
+    .hasLLC        = 0,
+    .hasERAM       = 0,
+    .InitMediaSysInfo = InitLCIAMediaSysInfo,
+    .InitShadowSku    = InitLCIAShadowSku,
+    .InitShadowWa     = InitLCIAShadowWa,
+};
+
+static struct GfxDeviceInfo glkGt1f5Info = {
+    .platformType  = PLATFORM_MOBILE,
+    .productFamily = IGFX_GEMINILAKE,
+    .displayFamily = IGFX_GEN9_CORE,
+    .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT1,
     .L3CacheSizeInKb = 384,
     .L3BankCount   = 2,
@@ -460,7 +511,8 @@ static struct GfxDeviceInfo kblGt1Info = {
     .productFamily = IGFX_KABYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
-    .eGTType       = GTTYPE_GT1,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
+    .eGTType       = GTTYPE_GT1_5,
     .L3CacheSizeInKb = 384,
     .L3BankCount   = 2,
     .EUCount       = 12,
@@ -480,6 +532,7 @@ static struct GfxDeviceInfo kblGt1f5Info = {
     .productFamily = IGFX_KABYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT1_5,
     .L3CacheSizeInKb = 768,
     .L3BankCount   = 4,
@@ -500,6 +553,7 @@ static struct GfxDeviceInfo kblGt2Info = {
     .productFamily = IGFX_KABYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT2,
     .L3CacheSizeInKb = 768,
     .L3BankCount   = 4,
@@ -520,6 +574,7 @@ static struct GfxDeviceInfo kblGt3Info = {
     .productFamily = IGFX_KABYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT3,
     .L3CacheSizeInKb = 1536,
     .L3BankCount   = 8,
@@ -540,6 +595,7 @@ static struct GfxDeviceInfo kblGt3eInfo = {
     .productFamily = IGFX_KABYLAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT3,
     .L3CacheSizeInKb = 1536,
     .L3BankCount   = 8,
@@ -560,6 +616,7 @@ static struct GfxDeviceInfo cflGt1Info = {
     .productFamily = IGFX_COFFEELAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT1,
     .L3CacheSizeInKb = 384,
     .L3BankCount   = 2,
@@ -580,6 +637,7 @@ static struct GfxDeviceInfo cflGt2Info = {
     .productFamily = IGFX_COFFEELAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT2,
     .L3CacheSizeInKb = 768,
     .L3BankCount   = 4,
@@ -600,6 +658,7 @@ static struct GfxDeviceInfo cflGt3Info = {
     .productFamily = IGFX_COFFEELAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT3,
     .L3CacheSizeInKb = 1536,
     .L3BankCount   = 8,
@@ -620,6 +679,7 @@ static struct GfxDeviceInfo cflGt3eInfo = {
     .productFamily = IGFX_COFFEELAKE,
     .displayFamily = IGFX_GEN9_CORE,
     .renderFamily  = IGFX_GEN9_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT3,
     .L3CacheSizeInKb = 1536,
     .L3BankCount   = 8,
@@ -711,20 +771,23 @@ static bool sklDevice193b = DeviceInfoFactory<GfxDeviceInfo>::
 static bool sklDevice193d = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x193d, &sklGt4eInfo);
 
+static bool bxtDevice0a84 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x0a84, &bxtGt1f5Info);
+
 static bool bxtDevice1a84 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x1a84, &bxtGt1Info);
+    RegisterDevice(0x1a84, &bxtGt1f5Info);
 
 static bool bxtDevice1a85 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x1a85, &bxtGt1Info);
 
 static bool bxtDevice5a84 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x5a84, &bxtGt1Info);
+    RegisterDevice(0x5a84, &bxtGt1f5Info);
 
 static bool bxtDevice5a85 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x5a85, &bxtGt1Info);
 
 static bool glkDevice3a84 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x3184, &glkGt1Info);
+    RegisterDevice(0x3184, &glkGt1f5Info);
 
 static bool glkDevice3a85 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x3185, &glkGt1Info);
@@ -894,11 +957,25 @@ static bool cmlDevice9bc0 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x9bc0, &cflGt2Info);
 static bool cmlDevice9bc5 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x9bc5, &cflGt2Info);
+static bool cmlDevice9bc6 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x9bc6, &cflGt2Info);
 static bool cmlDevice9bc8 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x9bc8, &cflGt2Info);
 static bool cmlDevice9bc4 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x9bc4, &cflGt2Info);
 static bool cmlDevice9bc2 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x9bc2, &cflGt2Info);
+static bool cmlDevice9be6 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x9be6, &cflGt2Info);
 static bool cmlDevice9bf6 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x9bf6, &cflGt2Info);
+
+/* AML/KBL Y GT2 */
+static bool cmlDevice591c = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x591C, &cflGt2Info);
+static bool cmlDevice87C0 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x87C0, &cflGt2Info);
+
+/* AML/CFL Y GT2 */
+static bool cmlDevice87ca = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x87ca, &cflGt2Info);
