@@ -22,13 +22,13 @@
 
 #include "MDF_FC_common_genx.h"
 
-_GENX_MAIN_ void Interlace_420_16_Buf_0(
+_GENX_MAIN_ void Interlace_444_16_Buf_0(
     CURBE_INPUT_OUTPUT,
     GLOBAL_BUFFER_INPUT_OUTPUT)
 {
-#define OUTPUT_420
+#define OUTPUT_PA
 #define BUFFER_0
 #include "Interlace_Buf.h"
 #undef BUFFER_0
-#undef OUTPUT_420
+#undef OUTPUT_PA
 }
\ No newline at end of file
