@@ -125,7 +125,7 @@ void HevcEncodeCqp::UpdateRDOQCfg()
 {
     ENCODE_FUNC_CALL();
 
-    // RDOQ by default enable for all TUs, but disable for SCC palette mode
+    // RDOQ disable for SCC palette mode
     auto hevcFeature = dynamic_cast<HevcBasicFeature *>(m_basicFeature);
     ENCODE_CHK_NULL_NO_STATUS_RETURN(hevcFeature);
 
@@ -137,7 +137,7 @@ void HevcEncodeCqp::UpdateRDOQCfg()
     m_rdoqIntraTuThreshold = 0;
     if (m_rdoqEnable)
     {
-        if (2 == m_basicFeature->m_targetUsage || 4 == m_basicFeature->m_targetUsage)
+        if (1 == m_basicFeature->m_targetUsage || 2 == m_basicFeature->m_targetUsage || 4 == m_basicFeature->m_targetUsage || 6 == m_basicFeature->m_targetUsage)
         {
             m_rdoqIntraTuThreshold = 0xffff;
         }
