@@ -137,15 +137,11 @@ public:
         cmd.DW0.InstructionTargetOpcode = 0x41;
         cmd.DW0.ColorDepth              = params.dwColorDepth;
         cmd.DW1.DestinationPitch        = params.dwDstPitch - 1;
-        cmd.DW1.DestinationMocsValue    =
-            this->m_osItf->pfnCachePolicyGetMemoryObject(MOS_GMM_RESOURCE_USAGE_BLT_DESTINATION,
-                                                         m_osItf->pfnGetGmmClientContext(m_osItf)).DwordValue;
+        cmd.DW1.DestinationMocsValue    = GetBlockCopyBltMOCS(MOS_GMM_RESOURCE_USAGE_BLT_DESTINATION);
 
         cmd.DW1.DestinationTiling             = GetFastTilingMode(dstTiledMode);
         cmd.DW8.SourceTiling                  = GetFastTilingMode(srcTiledMode);
-        cmd.DW8.SourceMocs                    =
-            this->m_osItf->pfnCachePolicyGetMemoryObject(MOS_GMM_RESOURCE_USAGE_BLT_SOURCE,
-                                                         m_osItf->pfnGetGmmClientContext(m_osItf)).DwordValue;
+        cmd.DW8.SourceMocs                    = GetBlockCopyBltMOCS(MOS_GMM_RESOURCE_USAGE_BLT_SOURCE);
 
         cmd.DW2.DestinationX1CoordinateLeft   = 0;
         cmd.DW2.DestinationY1CoordinateTop    = 0;
@@ -219,10 +215,30 @@ public:
             cmd.DW0.ColorDepth, cmd.DW8.SourcePitch, cmd.DW8.SourceMocs, cmd.DW8.SourceTiling, srcMmcModel,
             cmd.DW1.DestinationPitch, cmd.DW1.DestinationMocsValue, cmd.DW1.DestinationTiling, dstMmcModel);
 
+        MT_LOG7(MT_MEDIA_COPY, MT_NORMAL, MT_GENERIC_VALUE, cmd.DW0.ColorDepth, MT_GENERIC_VALUE, cmd.DW1.Value, MT_GENERIC_VALUE, cmd.DW2.Value, MT_GENERIC_VALUE, cmd.DW3.Value,
+                MT_GENERIC_VALUE, cmd.DW6.Value, MT_GENERIC_VALUE, cmd.DW7.Value, MT_GENERIC_VALUE, cmd.DW8.Value);
+        MT_LOG7(MT_MEDIA_COPY, MT_NORMAL, MT_GENERIC_VALUE, cmd.DW11.Value, MT_GENERIC_VALUE, cmd.DW16.Value, MT_GENERIC_VALUE, cmd.DW17.Value,
+                    MT_GENERIC_VALUE, cmd.DW18.Value, MT_GENERIC_VALUE, cmd.DW19.Value, MT_GENERIC_VALUE, cmd.DW20.Value, MT_GENERIC_VALUE, cmd.DW21.Value);
         return MOS_STATUS_SUCCESS;
     }
 
 protected:
+    //!
+    //! \brief    Get Block copy MOCS
+    //! \details  BLT function to get the MOCS
+    //! \param    [in] MOS_HW_RESOURCE_DEF
+    //!           Pointer to UsageDef
+    //! \return   uint32_t
+    //!           return the MOCS value
+    //!
+    virtual uint32_t GetBlockCopyBltMOCS(MOS_HW_RESOURCE_DEF UsageDef)
+    {
+        // MemoryObject will get 7 bits data. only bits[1-7] save MOCS, while some
+        // platoforms only use 4 bits mocs.
+        return (m_osItf->pfnCachePolicyGetMemoryObject(UsageDef,
+                    m_osItf->pfnGetGmmClientContext(m_osItf)).DwordValue & 0x1E) >>1;
+    }
+
     using base_t = Itf;
 MEDIA_CLASS_DEFINE_END(mhw__blt__Impl)
 };
