@@ -470,16 +470,13 @@ void Mos_AddIndirectState(
     const char          *stateName)
 {
     MOS_OS_CHK_NULL_NO_STATUS_RETURN(pOsInterface);
+    MOS_OS_CHK_NULL_NO_STATUS_RETURN(pOsInterface->osStreamState);
     if (pOsInterface->apoMosEnabled)
     {
-        MOS_OS_CHK_NULL_NO_STATUS_RETURN(pOsInterface->osStreamState);
-        INDIRECT_STATE_INFO stateinfoarray = {};
-        stateinfoarray.stateSize           = stateSize;
-        stateinfoarray.indirectState       = pIndirectState;
-        stateinfoarray.gfxAddressBottom    = gfxAddressBottom;
-        stateinfoarray.gfxAddressTop       = gfxAddressTop;
-        stateinfoarray.stateName           = stateName;
-        pOsInterface->osStreamState->indirectStateInfo.push_back(stateinfoarray);
+        if (MOS_STATUS_SUCCESS != MosInterface::AddIndirectState(pOsInterface->osStreamState, stateSize, pIndirectState, gfxAddressBottom, gfxAddressTop, stateName))
+        {
+            MOS_OS_ASSERTMESSAGE("Fail to Add Indirect State to Dump List");
+        }
     }
     return;
 }
@@ -931,7 +928,7 @@ MOS_STATUS Mos_InitOsInterface(
         MediaUserSetting::Group::Device);
 #endif
 
-    if (pOsInterface->apoMosEnabled || pOsInterface->apoMosForLegacyRuntime)
+    if (pOsInterface->apoMosEnabled)
     {
         pOsInterface->osStreamState->osCpInterface = pOsInterface->osCpInterface;
     }
